@@ -3,8 +3,8 @@
 
 /*
  * $Author: tom $
- * $Date: 2016/11/20 20:14:41 $
- * $Revision: 1.146 $
+ * $Date: 2021/12/16 01:09:14 $
+ * $Revision: 1.149 $
  */
 
 /*
@@ -227,11 +227,11 @@ int activateCDKRadio (CDKRADIO *radio, chtype *actions)
 
    if (actions == 0)
    {
-      chtype input;
       boolean functionKey;
 
       for (;;)
       {
+	 chtype input;
 	 int ret;
 
 	 fixCursorPosition (radio);
@@ -552,7 +552,7 @@ static void drawCDKRadioList (CDKRADIO *radio, boolean Box)
 				  getmaxy (radio->scrollbarWin) - 1);
 
       (void)mvwvline (radio->scrollbarWin, 0, 0,
-		      ACS_CKBOARD, getmaxy (radio->scrollbarWin));
+		      CDK_FILLED_BOX, getmaxy (radio->scrollbarWin));
       (void)mvwvline (radio->scrollbarWin, radio->togglePos, 0,
 		      ' ' | A_REVERSE, radio->toggleSize);
    }
@@ -797,6 +797,14 @@ static int createList (CDKRADIO *radio, CDK_CSTRING2 list, int listSize, int box
    int status = 0;
    int widestItem = 0;
 
+   if (radio->listSize > 0)
+   {
+      CDKfreeChtypes (radio->item);
+      radio->item = 0;
+      freeAndNull (radio->itemLen);
+      freeAndNull (radio->itemPos);
+   }
+
    if (listSize >= 0)
    {
       /* *INDENT-EQLS* */
@@ -828,9 +836,11 @@ static int createList (CDKRADIO *radio, CDK_CSTRING2 list, int listSize, int box
 	 {
 	    destroyInfo (radio);
 
-	    radio->item = newList;
-	    radio->itemLen = newLen;
-	    radio->itemPos = newPos;
+	    /* *INDENT-EQLS* */
+	    radio->listSize = listSize;
+	    radio->item     = newList;
+	    radio->itemLen  = newLen;
+	    radio->itemPos  = newPos;
 	 }
 	 else
 	 {
