@@ -3,8 +3,8 @@
 
 /*
  * $Author: tom $
- * $Date: 2016/11/20 19:25:35 $
- * $Revision: 1.156 $
+ * $Date: 2021/12/16 01:09:14 $
+ * $Revision: 1.159 $
  */
 
 /*
@@ -240,11 +240,11 @@ int activateCDKSelection (CDKSELECTION *selection, chtype *actions)
 
    if (actions == 0)
    {
-      chtype input;
       boolean functionKey;
 
       for (;;)
       {
+	 chtype input;
 	 int ret;
 
 	 fixCursorPosition (selection);
@@ -571,7 +571,7 @@ static void drawCDKSelectionList (CDKSELECTION *selection, boolean Box GCC_UNUSE
       selection->togglePos = MINIMUM (selection->togglePos,
 				      (getmaxy (selection->scrollbarWin) - 1));
 
-      (void)mvwvline (selection->scrollbarWin, 0, 0, ACS_CKBOARD, getmaxy (selection->scrollbarWin));
+      (void)mvwvline (selection->scrollbarWin, 0, 0, CDK_FILLED_BOX, getmaxy (selection->scrollbarWin));
       (void)mvwvline (selection->scrollbarWin,
 		      selection->togglePos,
 		      0,
@@ -933,6 +933,16 @@ static int createList (CDKSELECTION *selection, CDK_CSTRING2 list, int listSize)
    int status = 0;
    int widestItem = 0;
 
+   if (selection->listSize > 0)
+   {
+      CDKfreeChtypes (selection->item);
+      selection->item = 0;
+      freeAndNull (selection->itemLen);
+      freeAndNull (selection->itemPos);
+      freeAndNull (selection->selections);
+      freeAndNull (selection->mode);
+   }
+
    if (listSize >= 0)
    {
       /* *INDENT-EQLS* */
@@ -970,11 +980,12 @@ static int createList (CDKSELECTION *selection, CDK_CSTRING2 list, int listSize)
 	    destroyInfo (selection);
 
 	    /* *INDENT-EQLS* */
-	    selection->item      = newList;
-	    selection->itemPos   = newPos;
-	    selection->itemLen   = newLen;
+	    selection->listSize   = listSize;
+	    selection->item       = newList;
+	    selection->itemPos    = newPos;
+	    selection->itemLen    = newLen;
 	    selection->selections = newSel;
-	    selection->mode      = newMode;
+	    selection->mode       = newMode;
 	 }
 	 else
 	 {
